@@ -220,7 +220,7 @@ main (int argc, char *argv[])
 
   g_unsetenv ("GIO_USE_VFS");
 
-  context = g_option_context_new (_("- GNOME initial setup"));
+  context = g_option_context_new (_("— GNOME initial setup"));
   g_option_context_add_main_entries (context, entries, NULL);
 
   g_option_context_parse (context, &argc, &argv, NULL);
